function [tri, xyz] = ReadPLY(name)
%
%
%   [tri, xyz] = ReadPLY(name)
%
%       --Input:
%       name: input file name as a string
%
%       --Output:
%       tri: a n-3 matrix containing indices to vertices in xyz
%
%       xyz: a m-3 matrix containing vertex positions
%

try
    fid = fopen(name, 'r');

    tri = [];
    xyz = [];

    %read the header
    str = fscanf(fid, '%s', 1);
    if(strcmp(str, 'ply') == 0)
       error('This is not a valid PLY file'); 
    end

    str = fgetl(fid);
    str = fgetl(fid);

    if(strcmp(str, 'format ascii 1.0') == 0)
       error('This is not a valid PLY file');    
    end

    str = fgetl(fid);
    bVertex = 0;
    bFace = 0;
    nProperties = 0;
    nPropertiesFace = 0;

    while(strcmp(str, 'end_header') == 0)

        value = strfind(str, 'element vertex');
        if(~isempty(value))
            bVertex = 1;        
            nv = str2num(str((value + 14):end));
        end

        value = strfind(str, 'element face');
        if(~isempty(value))
            bVertex = 0; 
            bFace = 1;
            ntri = str2num(str((value + 12):end));
        end    

        if(bVertex)
            value = strfind(str, 'property');
            if(~isempty(value))
                nProperties = nProperties + 1;
            end
        end

        if(bFace) 
            value = strfind(str, 'property');
            if(~isempty(value))
                nPropertiesFace = nPropertiesFace + 1;
            end        
        end


        str = fgetl(fid);
    end

    %read the body

    %read vertices
    for i=1:nv
        vtx = fscanf(fid, '%f', nProperties);
        xyz = [xyz; vtx'];
    end

    %read faces
    for i=1:ntri
        nFace = fscanf(fid, '%d', 1);
        face = fscanf(fid, '%f', nFace);
        tri = [tri; face'];
    end

    %MATLAB indices start at 1!
    tri = tri + 1;

    fclose(fid);
catch expr    
    disp(expr);
end

end