function nor = ComputeFaceNormals(tri, xyz)
%
%
%        nor = ComputeFaceNormals(tri, xyz)
%
%       --Input:
%       tri: a n-3 matrix containing indices to vertices in xyz
%
%       xyz: a m-3 matrix containing vertex positions
%
%       --Output:
%       nor:  a n-3 matrix containing vertices normals
%

nor = zeros(size(tri, 1), 3);

for i=1:size(tri, 1)        
    i1 = tri(i, 1);
    i2 = tri(i, 2);
    i3 = tri(i, 3);
    
    V1 = xyz(i1, :);
    V2 = xyz(i2, :);
    V3 = xyz(i3, :);
    
    e32 = (V3 - V2);
    e12 = (V1 - V2);
    
    nor(i, :) = cross(e32, e12);

    tmp_norm = sqrt(sum(nor(i, :).^2));

    if(tmp_norm > 0.0)
        nor(i,:) = nor(i,:) / tmp_norm;
    end
end

end
